"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Time = exports.HOURS = exports.UNIT = exports.TIMES_OF_DAY = void 0;
var number_1 = require("../utilities/number");
var TIMES_OF_DAY;
(function (TIMES_OF_DAY) {
    TIMES_OF_DAY["AM"] = "AM";
    TIMES_OF_DAY["PM"] = "PM";
})(TIMES_OF_DAY = exports.TIMES_OF_DAY || (exports.TIMES_OF_DAY = {}));
var UNIT;
(function (UNIT) {
    UNIT["TIMES_OF_DAY"] = "times";
    UNIT["HOUR"] = "hour";
    UNIT["MIN"] = "min";
    UNIT["SECONDS"] = "seconds";
})(UNIT = exports.UNIT || (exports.UNIT = {}));
exports.HOURS = [12, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
var DAY = 86400;
var HOUR = 3600;
var MIN = 60;
var Time = /** @class */ (function () {
    /**
     * Constructor
     * @param params hour, min, seconds
     */
    function Time(params) {
        var _a, _b, _c;
        Object.defineProperty(this, "passed", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.passed =
            (((_a = params.hour) !== null && _a !== void 0 ? _a : 0) * HOUR +
                ((_b = params.min) !== null && _b !== void 0 ? _b : 0) * MIN +
                ((_c = params.seconds) !== null && _c !== void 0 ? _c : 0)) %
                DAY;
    }
    /**
     * Constructor
     * @param time time string ex) "09:00:00"
     * @returns Time
     */
    Object.defineProperty(Time, "string", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (time) {
            time = time.toUpperCase();
            var timesOfDay;
            if (time.includes(TIMES_OF_DAY.AM) || time.includes(TIMES_OF_DAY.PM)) {
                timesOfDay = time.slice(0, 2);
                time = time.slice(3);
            }
            var splits = time.split(":");
            var hour = +splits[0] + (timesOfDay === "PM" ? 12 : 0);
            var min = +splits[1];
            var seconds = isNaN(+splits[2]) ? 0 : +splits[2];
            return new Time({ hour: hour, min: min, seconds: seconds });
        }
    });
    /**
     * Constructor
     * @param passed total of the passed time in seconds
     * @returns Time
     */
    Object.defineProperty(Time, "passed", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (passed) {
            var hour = (0, number_1.quotient)(passed, HOUR);
            var min = (0, number_1.quotient)(passed % HOUR, MIN);
            var seconds = (passed % HOUR) % MIN;
            return new Time({ hour: hour, min: min, seconds: seconds });
        }
    });
    /**
     * @returns Get whether it is AM or PM.
     */
    Object.defineProperty(Time.prototype, "getTimesOfDay", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.getHour() < 12 ? TIMES_OF_DAY.AM : TIMES_OF_DAY.PM;
        }
    });
    /**
     * @returns hour
     */
    Object.defineProperty(Time.prototype, "getHour", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return (0, number_1.quotient)(this.passed, HOUR);
        }
    });
    /**
     * @returns minute
     */
    Object.defineProperty(Time.prototype, "getMin", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return (0, number_1.quotient)(this.passed % HOUR, MIN);
        }
    });
    /**
     * @returns seconds
     */
    Object.defineProperty(Time.prototype, "getSeconds", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return (this.passed % HOUR) % MIN;
        }
    });
    /**
     * @returns total of the passed time in hour
     */
    Object.defineProperty(Time.prototype, "getHourPassed", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.passed / HOUR;
        }
    });
    /**
     * @returns total of the passed time in minute
     */
    Object.defineProperty(Time.prototype, "getMinPassed", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.passed / MIN;
        }
    });
    /**
     * @returns total of the passed time in seconds
     */
    Object.defineProperty(Time.prototype, "getSecondsPassed", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            return this.passed;
        }
    });
    /**
     * @param action hour to set
     */
    Object.defineProperty(Time.prototype, "setHour", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (action, timesOfDay) {
            var hoursToAdd = 0;
            if (timesOfDay === TIMES_OF_DAY.PM) {
                hoursToAdd = 12;
            }
            var hour = getState(action, this.getHour()) + hoursToAdd;
            var passed = this.getSecondsPassed() - this.getHour() * HOUR + hour * HOUR;
            this.setPassed(passed);
        }
    });
    /**
     * @param action minute to set
     */
    Object.defineProperty(Time.prototype, "setMin", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (action) {
            var min = getState(action, this.getMin());
            var passed = this.getSecondsPassed() - this.getMin() * MIN + min * MIN;
            this.setPassed(passed);
        }
    });
    /**
     * @param action seconds to set
     */
    Object.defineProperty(Time.prototype, "setSeconds", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (action) {
            var seconds = getState(action, this.getSeconds());
            var passed = this.getSecondsPassed() - this.getSeconds() + seconds;
            this.setPassed(passed);
        }
    });
    /**
     * @param passed total of the passed time in seconds to set
     */
    Object.defineProperty(Time.prototype, "setPassed", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (passed) {
            this.passed = passed % DAY;
        }
    });
    /**
     * @param hours hour to add
     * @param min minute to add
     * @param seconds seconds to add
     */
    Object.defineProperty(Time.prototype, "plus", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (_a) {
            var hour = _a.hour, min = _a.min, seconds = _a.seconds;
            var target = new Time({ hour: hour, min: min, seconds: seconds });
            var secondsPassed = this.getSecondsPassed();
            var targetSecondsPassed = target.getSecondsPassed();
            this.setPassed(secondsPassed + targetSecondsPassed);
        }
    });
    /**
     * @param show24Hour show in 24 hours
     * @param showSeconds show seconds in string
     * @returns time string ex) "09:00:00"
     */
    Object.defineProperty(Time.prototype, "getString", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (_a) {
            var show24Hour = _a.show24Hour, showSeconds = _a.showSeconds;
            var timeType = !show24Hour ? "".concat(this.getTimesOfDay(), " ") : "";
            var hour = (0, number_1.fillZero)(this.getHour() % (show24Hour ? 24 : 12));
            var min = (0, number_1.fillZero)(this.getMin());
            var seconds = showSeconds ? ":".concat((0, number_1.fillZero)(this.getSeconds())) : "";
            return "".concat(timeType).concat(hour, ":").concat(min).concat(seconds);
        }
    });
    return Time;
}());
exports.Time = Time;
var getState = function (action, prev) {
    var next;
    if (typeof action === "number") {
        next = action;
    }
    else {
        next = action(prev);
    }
    return next;
};
