import type { Properties, StandardLonghandProperties } from "csstype";
import { keyOf } from "../../common";
export interface SizePropsDeprecated {
    width?: number;
    height?: number;
}
export interface ContainerPropsDeprecated extends SizePropsDeprecated {
}
/**
 * PropTypes of All CSS Properties
 */
export declare type AllProperties = {
    [key in keyOf<Properties>]?: Properties[key];
};
/**
 * PropTypes of All CSS Properties
 */
export declare type AllLonghandProperties = {
    [key in keyOf<StandardLonghandProperties>]?: StandardLonghandProperties[key];
};
/**
 * Abbreviation Style Property Types of Layout
 */
export declare const LAYOUT_ABBR_PROPS: {
    readonly d: "display";
    readonly of: "overflow";
    readonly ps: "position";
    readonly v: "visibility";
    readonly z: "zIndex";
};
export declare type LayoutAbbrProps = {
    [key in keyOf<typeof LAYOUT_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Flex & Grid
 */
export declare const FLEX_GRID_ABBR_PROPS: {
    readonly ai: "alignItems";
    readonly jc: "justifyContent";
    readonly rg: "rowGap";
    readonly cg: "columnGap";
};
export declare type FlexGridAbbrProps = {
    [key in keyOf<typeof FLEX_GRID_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Flex
 */
export declare const FLEX_ABBR_PROPS: {
    readonly fd: "flexDirection";
    readonly ac: "alignContent";
    readonly fw: "flexWrap";
};
export declare type FlexAbbrProps = {
    [key in keyOf<typeof FLEX_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Grid
 */
export declare const GRID_ABBR_PROPS: {
    readonly gac: "gridAutoColumns";
    readonly gar: "gridAutoRows";
    readonly gaf: "gridAutoFlow";
    readonly gtc: "gridTemplateColumns";
    readonly gtr: "gridTemplateRows";
    readonly gta: "gridTemplateAreas";
};
export declare type GridAbbrProps = {
    [key in keyOf<typeof GRID_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Spacing
 */
export declare const SPACING_ABBR_PROPS: {
    readonly m: "margin";
    readonly mt: "marginTop";
    readonly mr: "marginRight";
    readonly mb: "marginBottom";
    readonly ml: "marginLeft";
    readonly p: "padding";
    readonly pt: "paddingTop";
    readonly pr: "paddingRight";
    readonly pb: "paddingBottom";
    readonly pl: "paddingLeft";
};
export declare type SpacingAbbrProps = {
    [key in keyOf<typeof SPACING_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Sizing
 */
export declare const SIZING_ABBR_PROPS: {
    readonly w: "width";
    readonly minW: "minWidth";
    readonly maxW: "maxWidth";
    readonly h: "height";
    readonly minH: "minHeight";
    readonly maxH: "maxHeight";
};
export declare type SizingAbbrProps = {
    [key in keyOf<typeof SIZING_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Font
 */
export declare const FONT_ABBR_PROPS: {
    readonly c: "color";
    readonly f: "font";
    readonly fst: "fontStyle";
    readonly fw: "fontWeight";
    readonly fs: "fontSize";
    readonly ff: "fontFamily";
    readonly fv: "fontVariant";
    readonly lh: "lineHeight";
    readonly ta: "textAlign";
    readonly tof: "textOverflow";
    readonly td: "textDecoration";
    readonly ws: "whiteSpace";
};
export declare type FontAbbrProps = {
    [key in keyOf<typeof FONT_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of List
 */
export declare const LIST_ABBR_PROPS: {
    readonly ls: "listStyle";
    readonly lst: "listStyleType";
    readonly lsp: "listStylePosition";
};
export declare type ListAbbrProps = {
    [key in keyOf<typeof LIST_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Background
 */
export declare const BACKGROUND_ABBR_PROPS: {
    readonly bg: "background";
    readonly bgc: "backgroundColor";
};
export declare type BackgroundAbbrProps = {
    [key in keyOf<typeof BACKGROUND_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Border
 */
export declare const BORDER_ABBR_PROPS: {
    readonly b: "border";
    readonly bt: "borderTop";
    readonly br: "borderRight";
    readonly bb: "borderBottom";
    readonly bl: "borderLeft";
    readonly o: "outline";
    readonly radius: "borderRadius";
};
export declare type BorderAbbrProps = {
    [key in keyOf<typeof BORDER_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Abbreviation Style Property Types of Effects
 */
export declare const EFFECT_ABBR_PROPS: {
    readonly bs: "boxShadow";
};
export declare type EffectAbbrProps = {
    [key in keyOf<typeof EFFECT_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * Common Abbreviation Style Property Types
 */
export declare const COMMON_ABBR_PROPS: {
    readonly bs: "boxShadow";
    readonly b: "border";
    readonly bt: "borderTop";
    readonly br: "borderRight";
    readonly bb: "borderBottom";
    readonly bl: "borderLeft";
    readonly o: "outline";
    readonly radius: "borderRadius";
    readonly bg: "background";
    readonly bgc: "backgroundColor";
    readonly c: "color";
    readonly f: "font";
    readonly fst: "fontStyle";
    readonly fw: "fontWeight";
    readonly fs: "fontSize";
    readonly ff: "fontFamily";
    readonly fv: "fontVariant";
    readonly lh: "lineHeight";
    readonly ta: "textAlign";
    readonly tof: "textOverflow";
    readonly td: "textDecoration";
    readonly ws: "whiteSpace";
    readonly w: "width";
    readonly minW: "minWidth";
    readonly maxW: "maxWidth";
    readonly h: "height";
    readonly minH: "minHeight";
    readonly maxH: "maxHeight";
    readonly m: "margin";
    readonly mt: "marginTop";
    readonly mr: "marginRight";
    readonly mb: "marginBottom";
    readonly ml: "marginLeft";
    readonly p: "padding";
    readonly pt: "paddingTop";
    readonly pr: "paddingRight";
    readonly pb: "paddingBottom";
    readonly pl: "paddingLeft";
    readonly d: "display";
    readonly of: "overflow";
    readonly ps: "position";
    readonly v: "visibility";
    readonly z: "zIndex";
};
export declare type CommonAbbrProps = {
    [key in keyOf<typeof COMMON_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
/**
 * All Abbreviation Style Property Types
 */
export declare const ALL_ABBR_PROPS: {
    readonly bs: "boxShadow";
    readonly b: "border";
    readonly bt: "borderTop";
    readonly br: "borderRight";
    readonly bb: "borderBottom";
    readonly bl: "borderLeft";
    readonly o: "outline";
    readonly radius: "borderRadius";
    readonly bg: "background";
    readonly bgc: "backgroundColor";
    readonly ls: "listStyle";
    readonly lst: "listStyleType";
    readonly lsp: "listStylePosition";
    readonly c: "color";
    readonly f: "font";
    readonly fst: "fontStyle";
    readonly fw: "fontWeight";
    readonly fs: "fontSize";
    readonly ff: "fontFamily";
    readonly fv: "fontVariant";
    readonly lh: "lineHeight";
    readonly ta: "textAlign";
    readonly tof: "textOverflow";
    readonly td: "textDecoration";
    readonly ws: "whiteSpace";
    readonly w: "width";
    readonly minW: "minWidth";
    readonly maxW: "maxWidth";
    readonly h: "height";
    readonly minH: "minHeight";
    readonly maxH: "maxHeight";
    readonly m: "margin";
    readonly mt: "marginTop";
    readonly mr: "marginRight";
    readonly mb: "marginBottom";
    readonly ml: "marginLeft";
    readonly p: "padding";
    readonly pt: "paddingTop";
    readonly pr: "paddingRight";
    readonly pb: "paddingBottom";
    readonly pl: "paddingLeft";
    readonly gac: "gridAutoColumns";
    readonly gar: "gridAutoRows";
    readonly gaf: "gridAutoFlow";
    readonly gtc: "gridTemplateColumns";
    readonly gtr: "gridTemplateRows";
    readonly gta: "gridTemplateAreas";
    readonly fd: "flexDirection";
    readonly ac: "alignContent";
    readonly ai: "alignItems";
    readonly jc: "justifyContent";
    readonly rg: "rowGap";
    readonly cg: "columnGap";
    readonly d: "display";
    readonly of: "overflow";
    readonly ps: "position";
    readonly v: "visibility";
    readonly z: "zIndex";
};
export declare type AllAbbrProps = {
    [key in keyOf<typeof ALL_ABBR_PROPS>]?: AllProperties[typeof ALL_ABBR_PROPS[key]];
};
